@@ -35,16 +35,17 @@
 
 // this should go into the orders_order class.
 define('ORDERSTATUS_PROPOSED','proposed');      // customer has placed order, but not confirmed it yet
+define('ORDERSTATUS_PENDING','pending');        // this order has been submitted for payment, but not yet approved.
 define('ORDERSTATUS_CONFIRMED','confirmed');    // customer has confirmed order, but not processed payment
-define('ORDERSTATUS_INVOICED','invoiced');      // customer has completed manual invoice process
+
 define('ORDERSTATUS_SUBMITTED','submitted');    // delete me?
+define('ORDERSTATUS_INVOICED','invoiced');      // customer has completed manual invoice process
 define('ORDERSTATUS_CANCELLED','cancelled');    // this order has been cancelled (by an admin, or by the user)
 define('ORDERSTATUS_PAID','paid');              // this order is paid in full
 define('ORDERSTATUS_HOLD','hold');              // this order is on hold
 define('ORDERSTATUS_BALANCEDUE','balancedue');  // this order has not been paid in full
 define('ORDERSTATUS_INCOMPLETE','incomplete');  // not all items for this order have been shipped
 define('ORDERSTATUS_COMPLETED','completed');    // this order has been paid in full, and shipped in full.
-define('ORDERSTATUS_PENDING','pending');        // this order has been submitted for payment, but not yet approved.
 define('ORDERSTATUS_SUBSCRIBED','subscribed');  // this order is a subscription only order, and is active.
 
 define('ITEMSTATUS_PENDING','pending');         // this service item has not been delivered
@@ -71,6 +72,12 @@ require_once($cgecommbase);
 class Orders extends CGEcommerceBase
 {
 
+  public function __construct()
+  {
+    parent::__construct();
+    $this->AddImageDir('icons');
+  }
+
   /*---------------------------------------------------------
    GetName()
    ---------------------------------------------------------*/
@@ -93,7 +100,7 @@ class Orders extends CGEcommerceBase
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.10.2';
+    return '1.13';
   }
 
 
@@ -173,7 +180,7 @@ class Orders extends CGEcommerceBase
    ---------------------------------------------------------*/
   function GetAdminSection()
   {
-    return 'content';
+    return 'ecommerce';
   }
 
 
@@ -204,12 +211,12 @@ class Orders extends CGEcommerceBase
    ---------------------------------------------------------*/
   function GetDependencies()
   {
-    return array('CGEcommerceBase'=>'1.2.2',
-		 'FrontEndUsers'=>'1.12.2',
-		 'CGExtensions'=>'1.19.4',
+    return array('CGEcommerceBase'=>'1.3.1',
+		 'FrontEndUsers'=>'1.12.8',
+		 'CGExtensions'=>'1.25',
 		 'CGSimpleSmarty'=>'1.3.1',
 		 'CMSMailer'=>'1.73.13',
-		 'CGPaymentGatewayBase'=>'1.0.9');
+		 'CGPaymentGatewayBase'=>'1.0.11');
   }
 
 
@@ -218,7 +225,7 @@ class Orders extends CGEcommerceBase
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return "1.8.1";
+    return "1.9.2";
   }
 	
 	
@@ -288,7 +295,7 @@ class Orders extends CGEcommerceBase
   function GetHeaderHTML()
   {
     global $gCms;
-    $config =& $gCms->GetConfig();
+    $config = $gCms->GetConfig();
     $output = '';
 
     $url = $config['root_url'].'/modules/'.$this->GetName().'/admin.css';
@@ -339,6 +346,24 @@ EOT;
   }
 
 
+  /*---------------------------------------------------------
+   GetEventHelp()
+   ---------------------------------------------------------*/
+  function GetEventHelp($event_name)
+  {
+    return $this->Lang('event_help_'.$event_name);
+  }	
+
+
+  /*---------------------------------------------------------
+   GetEventDescription()
+   ---------------------------------------------------------*/
+  function GetEventDescription($event_name)
+  {
+    return $this->Lang('event_desc_'.$event_name);
+  }	
+
+
   function GetUsername($uid)
   {
     $feu =& $this->GetModuleInstance('FrontEndUsers');
@@ -349,7 +374,7 @@ EOT;
   public function _getRealEncryptionKey()
   {
     global $gCms;
-    $config =& $gCms->GetConfig();
+    $config = $gCms->GetConfig();
     $key = $this->GetPreference('encryption_key');
     if( empty( $key ) ) return '';
     $key = md5($config['root_path'].' '.$key);
@@ -358,299 +383,6 @@ EOT;
   }
 
 
-  // todo: get this out of this file.
-/*
-  function ProcessGatewayResult($uid,$order_id,$payment_id,$status,$transaction_id,$amount,$gateway,$message,$email_addr = '')
-  {
-    global $gCms;
-    $db =& $gCms->GetDb();
-
-    //
-    // Get the data out of the order
-    //
-    $order_obj = $this->GetOrder($order_id);
-
-    if( $uid )
-      {
-	//Make sure someone isn't pulling a fast one by just trolling for order id's
-	$found_uid = $db->GetOne('SELECT feu_user_id FROM ' . cms_db_prefix() . 'module_orders WHERE id = ?', array($order_id));
-	if ($uid != $found_uid)
-	  {
-	    // attempted hack
-	    return $this->Lang('error_orderinvalid');
-	  }
-      }
-
-    // Get the email address
-    $billing = $order_obj->get_billing();
-    $tmp = $billing->get_email();
-    if( $tmp )
-      {
-	$email_addr = $tmp;
-      }
-    if( !$email_addr )
-      {
-	return $this->Lang('error_noemailaddress');
-      }
-
-    //
-    // try to find a payment that matches
-    //
-    $payment = $order_obj->get_payment_by_txn_id($transaction_id);
-    if( !$payment )
-      {
-	// so payment found, try to find one by it's id.
-	if( $payment_id > 0 )
-	  {
-	    $payment = $order_obj->get_payment_by_id($payment_id);
-	  }
-
-	if( !$payment )
-	  {
-	    // still no payment found, this could mean that
-	    // the gateway required credit card information but we're not storing it
-	    // in which case we gotta create a new payment object.
-	    $payment = new orders_payment();
-	    $payment->set_payment_date(cge_utils::db_time(time()));
-	    $payment->set_order_id($order_id);
-	    $order_obj->add_payment($payment);
-	  }
-      }
-    $payment->set_txn_id($transaction_id);
-    $payment->set_method(orders_payment::TYPE_ONLINE);
-    $payment->set_gateway($gateway);
-    $payment->set_amount($amount);
-
-    //
-    // And give everything to smarty
-    //
-    global $gCms;
-    $smarty =& $gCms->GetSmarty();
-    $smarty->assign('transaction_id',$transaction_id);
-    $smarty->assign('orders',$this);
-    $smarty->assign('message',$message);
-    $smarty->assign('gateway_status',$status);
-    $smarty->assign('email_address',$email_addr);
-2
-    $returnstatus = null;
-
-    // Update the payment.
-    switch( $status )
-      {
-      case PAYMENT_STATUS_APPROVED:
-	{
-	  $payment->set_status(orders_payment::STATUS_APPROVED);
-	  $smarty->assign('status','SUCCESS');
-	  $smarty->assign('transaction_id',$transaction_id);
-	  
-	  $this->Audit('',$this->GetName(),$this->Lang('msg_payment_received',$transaction_id,$amount,$order_id));
-	}
-	break;
-
-      case PAYMENT_STATUS_ERROR:
-	{
-	  // bad address or something
-	  $payment->set_status(orders_payment::STATUS_ERROR);
-	  if( !empty($message) ) 
-	    {
-	      $retstatus = $message;
-	    }
-	  else
-	    {
-	      $retstatus = $this->Lang('error_orderprocessing');
-	    }
-
-	  $this->Audit('',$this->GetName(),$this->Lang('msg_payment_error',$transaction_id,$order_id));
-	}
-	break;
-
-      case PAYMENT_STATUS_OTHER:
-	{
-	  // bad address or something
-	  $payment->set_status(orders_payment::STATUS_OTHER);
-	  if( !empty($message) ) 
-	    {
-	      $retstatus = $message;
-	    }
-	  else
-	    {
-	      $retstatus = $this->Lang('error_orderprocessing');
-	    }
-
-	  $this->Audit('',$this->GetName(),$this->Lang('msg_payment_error',$transaction_id,$order_id));
-	}
-	break;
-
-      case PAYMENT_STATUS_PENDING:
-	{
-	  // the gateway stuff worked, but we haven't had
-	  // final approval for the purchase yet.
-	  $cur_status = $payment->get_status();
-	  if( $cur_status == orders_payment::STATUS_PAID )
-	    {
-	      $this->Audit('',$this->GetName(),$this->Lang('msg_payment_setbackwards',$order_id));
-	    }
-	  else
-	    {
-	      $smarty->assign('status','PENDING');
-	      $payment->set_status(orders_payment::STATUS_PENDING);
-	      $this->Audit('',$this->GetName(),$this->Lang('msg_payment_pending',$order_id));
-	    }
-	}
-	break;
-
-      case PAYMENT_STATUS_DECLINED:
-	{
-	  $payment->set_status(orders_payment::STATUS_DECLINED);
-	  $this->Audit('',$this->GetName(),$this->Lang('msg_payment_declined',$transaction_id,$order_id));
-	}
-	break;
-
-      case PAYMENT_STATUS_CANCELLED:
-	{
-	  $payment->set_status(orders_payment::STATUS_CANCELLED);
-	  $this->Audit('',$this->GetName(),$this->Lang('msg_payment_cancelled',$transaction_id,$order_id));
-	}
-	break;
-
-      default:
-	$retstatus = $this->Lang('error_unknownstatus');
-	break;
-      }
-
-    if( $retstatus != '' )
-      {
-	// oops, we have an error
-	return $retstatus;
-      }
-
-    // figure out what the order status should be.
-    // there prolly should be some preferences to help in decision making.
-    $all_shipped = $order_obj->is_all_shipped();
-    $part_shipped = $order_obj->is_partially_shipped();
-    $none_shipped = (!$all_shipped && !$part_shipped)?TRUE:FALSE;
-    $all_paid    = ($order_obj->get_amount_due() > 0.0)?FALSE:TRUE;
-    $cur_status  = $order_obj->get_status();
-    $has_services = $order_obj->has_services();
-    $service_only = $order_obj->is_service_only();
-
-    switch( $cur_status )
-      {
-	// finished checking out... we can adjust it
-      case ORDERSTATUS_PROPOSED:
-      case ORDERSTATUS_CONFIRMED:
-      case ORDERSTATUS_PENDING:
-	// user was invoiced... why are we even getting here?
-      case ORDERSTATUS_INVOICED:
-	// statuses set automagically.. we can adjust it.
-      case ORDERSTATUS_PAID:
-      case ORDERSTATUS_BALANCEDUE:
-      case ORDERSTATUS_INCOMPLETE:
-	$order_obj->set_status(ORDERSTATUS_CONFIRMED);
-	if( $status == PAYMENT_STATUS_CANCELLED )
-	  {
-	    $order_obj->set_status(ORDERSTATUS_CANCELLED);
-	  }
-	else if( !$has_services )
-	  {
-	    // only products
-	    if( $all_shipped && $all_paid )
-	      {
-		$order_obj->set_status(ORDERSTATUS_COMPLETE);
-	      }
-	    else if( $all_shipped && !$all_paid )
-	      {
-		$order_obj->set_status(ORDERSTATUS_BALANCEDUE);
-	      }
-	    else if( $part_shipped && $all_paid )
-	      {
-		$order_obj->set_status(ORDERSTATUS_INCOMPLETE);
-	      }
-	    else if( $all_paid )
-	      {
-		$order_obj->set_status(ORDERSTATUS_PAID);
-	      }
-	  }
-	else
-	  {
-	    // have some services.
-	    if( !$all_paid )
-	      {
-		$order_obj->set_status(ORDERSTATUS_BALANCEDUE);
-	      }
-	  }
-	break;
-	
-	// completed already, shouldn't even get here.
-      case ORDERSTATUS_COMPLETED:
-	// admin set statuses... don't adjust.
-      case ORDERSTATUS_CANCELLED:
-      case ORDERSTATUS_HOLD:
-      default:
-	break;
-      }
-
-    // save the order
-    $order_obj->save();
-
-    // update smarty.
-    $smarty->assign('order',$order_obj->to_array());
-    $smarty->assign('order_obj',$order_obj);
-    $smarty->assign('ordernumber',$order_obj->get_invoice());
-
-    // do we need to send an email?
-    // actually, we could use a different template for each status... but we won't for now.
-    $sendemail = false;
-    switch($order_obj->get_status())
-      {
-      case ORDERSTATUS_COMPLETED:
-      case ORDERSTATUS_PAID:
-      case ORDERSTATUS_INVOICED:
-      case ORDERSTATUS_CONFIRMED:
-	$sendemail = true;
-	break;
-      }
-
-    // send it if we need to.
-    if( $sendemail )
-      {
-	// Send an email to the administrator
-	{
-	  $subject = $this->ProcessTemplateFromData($this->GetPreference('adminemail_subject'));
-	  $body = $this->ProcessTemplateFromData($this->GetPreference('adminemail_template'));
-	  $cmsmailer =& $this->GetModuleInstance('CMSMailer');
-	  $addresses = explode(',',$this->GetPreference('admin_email'));
-	  foreach( $addresses as $addr )
-	    {
-	      $cmsmailer->AddAddress($addr);
-	    }
-	  $cmsmailer->SetSubject($subject);
-	  $cmsmailer->SetBody($body);
-	  $cmsmailer->IsHTML(true);
-	  $cmsmailer->Send();
-	  $cmsmailer->reset();
-	}
-
-	// Send an email to the user
-	{
-	  $subject = $this->ProcessTemplateFromData($this->GetPreference('useremail_subject'));
-	  $body = $this->ProcessTemplateFromData($this->GetPreference('useremail_template'));
-	  $cmsmailer =& $this->GetModuleInstance('CMSMailer');
-	  $cmsmailer->AddAddress($email_addr);
-	  $cmsmailer->SetSubject($subject);
-	  $cmsmailer->SetBody($body);
-	  $cmsmailer->IsHTML(true);
-	  $cmsmailer->Send();
-	  $cmsmailer->reset();
-	}
-      }
-
-    // and we're done.
-    return;
-  }
-*/
-
-
   static public function &GetOrder($order_id)
   {
     //require_once(dirname(__FILE__).'/lib/class.orders_ops.php');
@@ -668,27 +400,6 @@ EOT;
   }
 
 
-//   public function IsValidUser()
-//   {
-//     $feu =& $this->GetModuleInstance('FrontEndUsers');
-//     if( !$feu ) return FALSE;
-
-//     $uid = $feu->LoggedInId();
-//     if( $uid <= 0 ) return FALSE;
-
-//     $grpid = $this->GetPreference('require_membership',-1);
-//     if( $grpid <= 0 ) return $uid;
-
-//     $data = $feu->GetMemberGroupsArray($uid);
-//     $gids = cge_array::extract_field($data,'groupid');
-//     if( !in_array( $grpid, $gids ) )
-//       {
-// 	return FALSE;
-//       }
-//     return $uid;
-//   }
-
-
   protected function get_country_list()
   {
     $tmp = $this->GetPreference('valid_countries','');
@@ -751,6 +462,9 @@ EOT;
 
     return FALSE;
   }
+
+  public function can_cache_output() { return FALSE; }
+
 } // class
 
 #
