@@ -1,5 +1,5 @@
 <?php
-$lang['0_product'] = 'Produkt';
+$lang['0_product'] = 'Product ';
 $lang['1_service'] = 'Service ';
 $lang['2_discount'] = 'Korting';
 $lang['3_shipping'] = 'Transport';
@@ -54,6 +54,7 @@ $lang['confirmed'] = 'Bevestigd';
 $lang['confirm_order'] = 'Bevestig order';
 $lang['confirmation_form_templates'] = 'Bevestigingssjablonen';
 $lang['confirmation_num'] = 'Bevestigingsnummer';
+$lang['cookie'] = 'Bewaar het adres in een cookie.';
 $lang['country'] = 'Land';
 $lang['coupon_code'] = 'Kortingscode';
 $lang['created'] = 'Gemaakt';
@@ -120,7 +121,7 @@ $lang['error_orderinvalid'] = 'Er is een probleem met deze order (de informatie
 $lang['error_ordernotfound'] = 'Gevraagde order niet gevonden';
 $lang['error_orderprocessing'] = 'Er is een fout opgetreden bij het verwerken van deze bestelling (soft fail)';
 $lang['error_paymentnotfound'] = 'De gespecificeerde betaling kan niet worden gevonden';
-$lang['error_possible_hack'] = 'Detected a possible hack: your uid (%s) does not match the uid (%s) found for order %s.  Please contact your system administrator.';
+$lang['error_possible_hack'] = 'Een mogelijke hack gedetecteerd: uw uid (%s) komt niet overeen met de uid (%s) gevonden voor de order %s.  Neem contact op met uw systeembeheerder.';
 $lang['error_requiressl'] = 'De voor gebruik op deze site geselecteerde gateway vereist een beveiligde verbinding, welke nog niet tot stand is gebracht';
 $lang['error_retrieve_data'] = 'Er is een probleem opgetreden bij het verkrijgen van informatie vanuit de database';
 $lang['error_save'] = 'Fout tijdens opslaan van data item: %s';
@@ -177,7 +178,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
-$lang['help_param_invoice_prefix'] = 'This parameter allows specifying up to 4 characters to be used as a prefix when generating the invoice number.  If this is not specified, the prefix used in the module preferences will be used.';
+$lang['help_param_invoice_prefix'] = 'Met deze parameter kunt u tot 4 tekens een prefix opgeven die wordt gebruikt voor het genereren van een ordernummer. Als dit niet is opgegeven, dan zal de prefix opgegeven in de module voorkeuren gebruikt worden.';
 $lang['help_param_nocaptcha'] = 'Inschakelen van deze parameter, schakelt Captcha uit';
 $lang['help_param_template'] = 'Specificeer een niet standaard sjabloon voor deze standaard actie';
 $lang['hold'] = 'Houd vast';
@@ -187,24 +188,26 @@ $lang['id'] = 'Id ';
 $lang['incomplete'] = 'Niet compleet (gedeeltelijk verzonden)';
 $lang['info_admin_invoice_template'] = 'Selecteer een sjabloon die moet worden gebruikt als er een printbare factuur popup wordt getoond wanneer een order word bewerkt.';
 $lang['info_adminemail_template'] = 'Dit sjabloon bevat the layout en inhoud van de e-mail die wordt verstuurd naar de geautoriseerde administrator wanneer er een order is geplaatst';
+$lang['info_allow_anon_checkout'] = 'Als dit is uitgeschakeld, dan zijn gebruikers vereist om een geldige FEU-login te hebben om het bestelproces te kunnen afronden.';
 $lang['info_allow_creditcard_entry'] = '<strong>Opmerking:</strong> Deze informatie is opgeslagen in de database.<br/>Ondanks dat er encryptie word gebruikt om de persoonsgebonden data op te slaan,<br/>is het aan te bevelen deze optie niet te gebruiken.<br/>Gebruik hiervoor een betalingsmodule (payment gateway module).';
 $lang['info_billingpage'] = '<strong>Opmerking:</strong> De instelling en andere die erop lijken worden gebruikt om de administrator om verschillende CMSMS pagina&#039;s te gebruiken voor de verschillende formulieren. Als er geen is geselecteerd, dan zal de huidige pagina worden gebruikt.';
 $lang['info_ccprocessing_module'] = 'Deze module wordt gebruikt voor het handmatig verwerken van creditcard gegevens';
 $lang['info_coupon_code'] = 'Voer een code in voor een mogelijke korting';
 $lang['info_default_templates'] = 'This form controls the content of the template when you click &#039;New Template&#039; in the &#039;Confirmation Form Templates&#039; tab.  Editing the text here will have no immediate effect on the appearance of your site';
-$lang['info_edit_report_template'] = 'These templates determine the style and layout for a particular report';
+$lang['info_edit_report_template'] = 'Dit sjabloon bepaalt de stijl en de lay-out voor een individueel rapport';
 $lang['info_encryption_key'] = 'Deze sleutel is willekeurig gegenereerd bij de module installatie. Wees voorzichtig bij het wijzigen van deze waarde als er al orders in het systeem staan.';
-$lang['info_forcessl'] = '<strong>Note: Recommended</strong>.  If you are allowing customers to enter credit card information, you should enable this option and ensure that you have properly configured your site for SSL access to ensure that the transmission of credit card information is done over an encrypted connection.';
-$lang['info_gateway_description'] = 'This information is sent to the payment gateway for each transaction, and may be used for information such as the name that shows up to clients on their credit card statements';
-$lang['info_incomplete_timeout'] = 'Proposed orders that have had no activity in a set number of minutes can be set to incomplete automatically.  Set the value to 0 to disable this functionality';
+$lang['info_forcessl'] = '<strong>Opmerking: Aanbevolen</strong>. Als u klanten toestaat om creditcard gegevens in te voeren, dan is het aan te raden om deze functie in te schakelen en u er van te verzekeren dat uw site beschikt over een goed geconfigureerde SSL-verbinding zodat de overdracht van de creditcard informatie beveiligd worden verzonden.';
+$lang['info_gateway_description'] = 'Deze informatie wordt verzonden naar de betaalgateway voor iedere transactie en kan worden gebruikt voor bijvoorbeeld de naam die wordt weergegeven bij de afhandeling van de betaling met een creditcard.  Dit is een smarty-sjabloon, het is dus mogelijk om de weergave aan te passen.';
+$lang['info_incomplete_timeout'] = 'Voorgestelde orders met een bepaalde inactieve tijd (in minuten) kunnen na die tijd automatisch de status &#039;incompleet&#039; krijgen. Als u de waarde instelt op 0, dan is deze functie uitgeschakeld.';
 $lang['info_invoicepage'] = '<strong>Opmerking:</strong> Deze pagina wordt ook gebruikt als succes- en foutpagina voor de betalingsgateway';
-$lang['inform_no_cc_processing'] = 'Are you aware that you are merely editing existing payment information?\nNo new credit card transaction will be processed.';
-$lang['info_order_notes'] = 'Geef specifieke notities op voor deze order';
-$lang['info_skip_invoice_page'] = 'When allowing users to specify payment information,<br/>should they then procede to the invoice page,<br/>or directly to the transaction completion page?';
-$lang['info_store_creditcard_data'] = '<strong>Note: <span style=&quot;color: red;&quot;>Not Recommended</span></strong> This information is stored in the database.  Although encryption is used to store private data it cannot be considered to be secure.  It is recommended that this option never be used.  Instead, please use a compatible payment gateway module.';
+$lang['inform_no_cc_processing'] = 'Weet u zeker dat u bestaande betaalinformatie wilt aanpassen?\nEr zal geen nieuwe creditcard transactie plaatsvinden.';
+$lang['info_order_notes'] = 'Geef speciale notities op voor deze order';
+$lang['info_require_membergroup'] = 'Deze instellingen zijn alleen van toepassing als het NIET is toegestaan voor anonieme gebruikers om een bestelling te plaatsen';
+$lang['info_skip_invoice_page'] = 'Indien u toestaat gebruikers betaalinformatie te op te geven<br/>moeten zij dan worden doorverwezen naar de factuurpagina,<br/>of direct naar de pagina met de voltooiing van de transactie?';
+$lang['info_store_creditcard_data'] = '<strong>Opmerking: <span style=&quot;color: red;&quot;>Niet aanbevolen</span></strong> Deze informatie wordt opgeslagen in de database. Ondanks dat er versleuteling wordt toegepast op de informatie, is dit niet volledig veilig. Het is aanbevolen deze optie niet te gebruiken. U kunt beter op zoek gaan naar een betere betaalgateway module.';
 $lang['info_useremail_template'] = 'Dit sjabloon bevat the layout en inhoud van de e-mail die wordt verstuurd naar de gebruiker wanneer een order is geplaatst';
-$lang['info_validcountries'] = 'Specify a list of country codes and country names (one entry per line) for the countries that will show up in the address list.  i.e: US=United States.  If no value is specified, the default country list will be used.';
-$lang['info_validstates'] = 'Specify a list of state codes and names (one entry per line) for the states or provinces that will show up in the address list.  i.e: AB=Alberta.  If no value is specified, the default state list will be used.';
+$lang['info_validcountries'] = 'Geef een lijst om met landcodes en landnamen (een per regel) voor de landen die moeten worden weergegeven in de adressenlijst. Bijvoorbeeld: NL=Nederland. Als er geen waarde is opgegeven, dan zal de standaard landenlijst worden gebruikt.';
+$lang['info_validstates'] = 'Geef een lijst op met codes en namen van staten of provincies (een per regel). Deze zullen worden weergegeven in de adressen lijst. Bijvoorbeeld: GL=Gelderland. Als er geen waarde is opgegeven, dan zal de standaard lijst worden gebruikt.';
 $lang['info_use_integer'] = 'Gebruik alleen integere waarden';
 $lang['interval_oneday'] = 'E&eacute;n dag';
 $lang['interval_onemonth'] = 'E&eacute;n maand';
@@ -235,12 +238,12 @@ $lang['msg_order_cancelled'] = 'Order %s geannuleerd of niet geaccepteerd';
 $lang['msg_order_error'] = 'Fout opgetreden bij order %s';
 $lang['msg_order_payment'] = 'Betaling ontvangen voor order %s.';
 $lang['msg_order_pending'] = 'Order status gewijzigd naar &quot;In behandeling&quot; voor %s';
-$lang['msg_payment_cancelled'] = 'Payment %s was cancelled for order %s';
-$lang['msg_payment_declined'] = 'Payment %s was declined for order %s';
-$lang['msg_payment_error'] = 'An error occurred on payment %s for order %s';
-$lang['msg_payment_received'] = 'Payment %s (%s) was received for order %s';
+$lang['msg_payment_cancelled'] = 'Betaling %s is geannuleerd voor de order %s';
+$lang['msg_payment_declined'] = 'Betaling %s is geweigerd voor de order %s';
+$lang['msg_payment_error'] = 'Er is een fout opgetreden voor de betaling %s van de order %s';
+$lang['msg_payment_received'] = 'Betaling %s (%s) is ontvangen voor de order %s';
 $lang['msg_payment_removed'] = 'Betaling van de order verwijderd';
-$lang['msg_payment_setbackwards'] = 'Attempted to set status of order %s backwards from PAID to PENDING';
+$lang['msg_payment_setbackwards'] = 'Geprobeerd om de status van de order %s te wijzigen van BETAALD naar WACHTEND';
 $lang['name'] = 'Naam';
 $lang['net'] = 'Netto';
 $lang['net_price'] = 'Netto Prijs';
@@ -304,11 +307,12 @@ $lang['promotions_settings'] = 'Promotions Instellingen';
 $lang['prompt_address_property_map'] = 'Adres op FEU Property Map';
 $lang['prompt_address_retrieval'] = 'Adres opzoek methode';
 $lang['prompt_admin_invoice_template'] = 'Te printen factuur sjabloon';
+$lang['prompt_allow_anon_checkout'] = 'Sta anonieme gebruikers toe om te bestellen';
 $lang['prompt_allow_creditcard_entry'] = 'Sta klanten toe om hun Credit Card gegevens in te voeren';
 $lang['prompt_billingpage'] = 'Pagina waar de factuur wordt getoond.  Dit is meestal de pagina met de <code>{Orders}</code> tag.';
 $lang['prompt_ccprocessing_module'] = 'Credit Card Verwerking Gateway';
 $lang['prompt_confirmpage'] = 'Te gebruiken pagina voor het tonen van het bevestigingsformulier';
-$lang['prompt_datastore_timeout'] = 'Expiry period for temporary transaction information';
+$lang['prompt_datastore_timeout'] = 'Verloopperiode voor tijdelijke transactie informatie';
 $lang['prompt_date_search_type'] = 'Filter Records die zijn';
 $lang['prompt_dflt_country'] = 'Standaard land';
 $lang['prompt_dflt_state'] = 'Standaard staat';
@@ -316,7 +320,7 @@ $lang['prompt_email'] = 'E-mail adres';
 $lang['prompt_encryption_key'] = 'Encryptiesleutel';
 $lang['prompt_forcessl'] = 'Verwijs de pagina naar HTTPS voor de invoer van betalingsgegevens';
 $lang['prompt_gateway_description'] = 'Omschrijving om naar de betalingsgateway te sturen';
-$lang['prompt_incomplete_timeout'] = 'Automatically set orders to incomplete <em>(if proposed)</em> after N minutes';
+$lang['prompt_incomplete_timeout'] = 'Zet orders automatisch op incompleet <em>(indien voorgesteld)</em> na N minuten';
 $lang['prompt_invoice_message'] = 'Bericht dat boven alle facturen getoond moet worden';
 $lang['prompt_invoicepage'] = 'Te gebruiken pagina voor het tonen van de factuur';
 $lang['prompt_of'] = 'Van';
@@ -325,14 +329,14 @@ $lang['prompt_page'] = 'Pagina';
 $lang['prompt_pagelimit'] = 'Aantal Orders per pagina';
 $lang['prompt_paymentpage'] = 'Te gebruiken pagina voor het betalingsformulier';
 $lang['prompt_permit_deletion'] = 'Sta het verwijderen van orders toe';
-$lang['prompt_requirepostal'] = 'Postal/Zip code is a required field on the billing form';
-$lang['prompt_requirestate'] = 'State/Province is a required field in the billing form';
+$lang['prompt_requirepostal'] = 'Postcode is een vereist veld op het betalingsformulier';
+$lang['prompt_requirestate'] = 'Provincie is een vereist veld op het betalingsformulier';
 $lang['prompt_skip_invoice_page'] = 'Sla factuurpagina over';
 $lang['prompt_store_creditcard_data'] = 'Credit Card Informatie Opslaan';
 $lang['prompt_template'] = 'Berichtsjabloon';
 $lang['prompt_username'] = 'Gebruikersnaam';
-$lang['prompt_validcountries'] = 'Valid Countries:';
-$lang['prompt_validstates'] = 'Valid States:';
+$lang['prompt_validcountries'] = 'Geldige landen:';
+$lang['prompt_validstates'] = 'Geldige provincies:';
 $lang['proposed'] = 'Voorgesteld';
 $lang['quantity'] = 'Hoeveelheid';
 $lang['really_uninstall'] = 'Weet u zeker dat u dit wilt doen? Alle data geassocieerd met deze module zal worden verwijderd.';
@@ -343,7 +347,7 @@ $lang['report'] = 'Rapport';
 $lang['reports'] = 'Rapporten';
 $lang['report_recent_payments'] = 'Recente betalingen';
 $lang['report_shipping_costs'] = 'Transportkosten';
-$lang['report_subscr_picklist'] = 'Subscription Picklist';
+$lang['report_subscr_picklist'] = 'Abonnementen keuzelijst';
 $lang['report_templates'] = 'Rapport Sjablonen';
 $lang['return'] = 'Terug';
 $lang['require_group_membership'] = 'Verplicht alle gebruikers die een order plaatsen lid te zijn van een FEU groep';
@@ -366,17 +370,18 @@ $lang['shipping_message'] = 'Bericht in relatie tot de bestemming';
 $lang['shipping_module'] = 'Shipping Module ';
 $lang['shipping_settings'] = 'Shipping instellingen';
 $lang['shipping_total'] = 'Verzendtotaal';
-$lang['sku'] = 'SKU';
+$lang['sku'] = 'SKU ';
 $lang['source'] = 'Bron';
 $lang['special_instructions'] = 'Speciale instructies';
 $lang['start_date'] = 'Start Datum';
 $lang['state/province'] = 'Provincie';
 $lang['status'] = 'Status ';
-$lang['subscription'] = 'Subscription';
+$lang['subscription'] = 'Abonnementen';
 $lang['subject'] = 'Onderwerp';
 $lang['submit'] = 'Verzend';
 $lang['submitted'] = 'Verzonden';
 $lang['submit_payment_info'] = 'Verzend betaalinformatie';
+$lang['subscribed'] = 'Geabonneerd';
 $lang['subtotal'] = 'Subtotaal';
 $lang['tax'] = 'BTW';
 $lang['tax_module'] = 'BTW Module';
@@ -409,18 +414,18 @@ $lang['user_email_template'] = 'Gebruikers E-mail Sjabloon';
 $lang['view'] = 'Bekijk';
 $lang['view_message'] = 'Bekijk bericht';
 $lang['view_messages'] = 'Bekijk berichten behorende bij deze order';
-$lang['warning_https'] = '<strong>Warning!</strong> You are not using a secure (https) connection.  It is not recommended that you continue with this action without a secure connection.';
-$lang['warning_manual_process'] = '<strong>Warning!</strong> This screen allows manual processing of credit card transactions using an online gateway.  Use caution!';
+$lang['warning_https'] = '<strong>Waarschuwing!</strong> U gebruikt geen veilige (https) verbinding. Het is niet aanbevolen om verder te gaan met deze actie zonder een beveiligde verbinding.';
+$lang['warning_manual_process'] = '<strong>Waarschuwing!</strong> Dit scherm staat u toe om handmatige uitvoer van credit card transacties te doen via een online gateway. Wees voorzichtig!';
 $lang['warning_orderstatus_paid'] = '<strong>Waarschuwing!</strong> - Deze order is al betaald. U moet niet verder gaan met de betalingsactie van de order';
 $lang['warning_orderstatus_cancelled'] = '<strong>Waarschuwing!</strong> - De order is geannuleerd. U moet niet verder gaan met de betalingsactie van de order';
-$lang['warning_no_ccprocessing_gateway'] = '<strong>Warning!</strong> Although you may enter credit card information for a new or existing payment, no online processing will occur.';
+$lang['warning_no_ccprocessing_gateway'] = '<strong>Waarschuwing!</strong> Hoewel u misschien credit card gegevens wilt invoeren voor een nieuwe of bestaande betaling zal geen online verwerking plaatsvinden.';
 $lang['warning_order_paid_in_full'] = '<strong>Waarschuwing!</strong> Deze order lijkt al volledig betaald te zijn.';
 $lang['weight'] = 'Gewicht';
 $lang['within'] = 'Tussen';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.859862155.1275574501.1276000318.1276003303.25';
-$lang['utmz'] = '156861353.1275860456.18.6.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=tinymce {#advlink';
-$lang['qca'] = 'P0-846565211-1275574501936';
-$lang['utmb'] = '156861353.1.10.1276003303';
+$lang['utma'] = '156861353.1852221271.1287479092.1305060417.1305098379.144';
+$lang['utmz'] = '156861353.1305060417.143.89.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['qca'] = 'P0-161031897-1287479092171';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
