@@ -54,6 +54,7 @@ $lang['confirmed'] = 'Bekr&auml;ftad';
 $lang['confirm_order'] = 'Bekr&auml;fta din order';
 $lang['confirmation_form_templates'] = 'Bekr&auml;ftelsemallar';
 $lang['confirmation_num'] = 'Bekr&auml;ftelsenummer';
+$lang['cookie'] = 'Use address stored in a cookie';
 $lang['country'] = 'Land';
 $lang['coupon_code'] = 'Coupon Kod';
 $lang['created'] = 'Skapad';
@@ -67,8 +68,8 @@ $lang['creditcard_type'] = 'Kreditkorttyp';
 $lang['creditcard_verifycode'] = 'Veriferingskod';
 $lang['customer_name'] = 'Kundens namn';
 $lang['date'] = 'Datum';
-$lang['date_range'] = 'Date Range';
-$lang['dateopt_exactdates'] = 'Exact Dates';
+$lang['date_range'] = 'Datumintervall';
+$lang['dateopt_exactdates'] = 'Exakta datum';
 $lang['dateopt_7days'] = 'Senaste 7 dagarna';
 $lang['dateopt_14days'] = 'Senaste 14 dagarna';
 $lang['dateopt_30days'] = 'Senaste 30 dagarna';
@@ -106,13 +107,13 @@ $lang['error_gateway_invalid_data'] = 'Could not confirm data validity from paym
 $lang['error_insufficientparams'] = 'En n&ouml;dv&auml;ndig parameter saknades';
 $lang['error_invalid_address'] = 'The address specified is invalid (please ensure you completed all required fields correctly)';
 $lang['error_invalidfield'] = 'F&ouml;ljande f&auml;lt &auml;r ogiltig: %s';
-$lang['error_invalidgateway'] = 'The selected gateway module is invalid for this purpose';
+$lang['error_invalidgateway'] = 'Den valda gatewaymodulen &auml;r ogiltig f&ouml;r detta &auml;ndam&aring;l';
 $lang['error_missingshippinginfo'] = 'Otillr&auml;cklig fraktinformation &auml;r angiven';
 $lang['error_namexists'] = 'Ett objekt med detta namn finns redan';
 $lang['error_nocartmodule'] = 'Hittade inte Cart modulen.  V&auml;nligen kontrollera att Cart modulen &auml;r installerad och &auml;r vald i  Products modulens inst&auml;llningar.';
 $lang['error_noemailaddress'] = 'Ingen epostadress har satts i samband med detta anv&auml;ndarid ';
 $lang['error_nofeumodule'] = 'Kunde inte hitta FrontEndUsers modulen';
-$lang['error_nopaymentgateway'] = 'No payment gateway specified';
+$lang['error_nopaymentgateway'] = 'Ingen betalnings gateway &auml;r angiven';
 $lang['error_noproductsmodule'] = 'Kunde inte hitta modulen Products';
 $lang['error_norequiredgroup'] = 'V&auml;nligen ange en obligatorisk grupp i inst&auml;llningsdelen';
 $lang['error_notloggedin'] = 'Anv&auml;ndaren &auml;r inte inloggad';
@@ -135,6 +136,7 @@ $lang['first_name'] = 'F&ouml;rnamn';
 $lang['firstpage'] = '<<';
 $lang['friendlyname'] = 'Order Hantering';
 $lang['from'] = 'Fr&aring;n';
+$lang['gateway'] = 'Gateway';
 $lang['gateway_module'] = 'Payment Gateway Modul';
 $lang['gateway_complete_templates'] = 'Gateway Complete Mallar';
 $lang['gateway_failure_message'] = 'Din transaktion slutf&ouml;rdes inte. Antingen avslutades operationen eller s&aring;s uppstod n&aring;got annat fel. Bekr&auml;fta din betalningsinformation och f&ouml;rs&ouml;k igen. Din kundvagn &auml;r t&ouml;md f&ouml;r din s&auml;kerhet och bekv&auml;mlighet. Tack f&ouml;r er tid';
@@ -186,10 +188,11 @@ $lang['id'] = 'ID';
 $lang['incomplete'] = 'Ofullst&auml;ndig (Delvis skickat)';
 $lang['info_admin_invoice_template'] = 'Select a template that will be used for the printable invoice popup display when managing an order';
 $lang['info_adminemail_template'] = 'This template controls the layout and content of the email that is sent to the authorized administrator when a new order is submitted';
+$lang['info_allow_anon_checkout'] = 'If disabled, users will be required to have a valid FEU login to be able to check out';
 $lang['info_allow_creditcard_entry'] = '<strong>Note:</strong> This information is stored in the database.<br/>Though encryption is used to store private data,<br/>it is recommended that this option never be used.<br/>Instead, please use a compatible payment gateway module.';
 $lang['info_billingpage'] = '<strong>Note:</strong> This preference, and the others like it are used to allow the administrator to use different CMSMS pages for the different forms.  If &quot;none&quot; is specified, then the current page will be used.';
-$lang['info_ccprocessing_module'] = 'This module is used for manual credit card processing';
-$lang['info_coupon_code'] = 'Enter a coupon code for a possible discount';
+$lang['info_ccprocessing_module'] = 'Denna modul anv&auml;nds f&ouml;r manuell kreditkorts hantering ';
+$lang['info_coupon_code'] = 'Ange en kupongkod f&ouml;r en eventuell rabatt';
 $lang['info_default_templates'] = 'This form controls the content of the template when you click &#039;New Template&#039; in the &#039;Confirmation Form Templates&#039; tab.  Editing the text here will have no immediate effect on the appearance of your site';
 $lang['info_edit_report_template'] = 'These templates determine the style and layout for a particular report';
 $lang['info_encryption_key'] = 'This key is randomly generated when the module is installed.  Use caution when changing this value if there are already orders in the system.';
@@ -199,6 +202,7 @@ $lang['info_incomplete_timeout'] = 'Proposed orders that have had no activity in
 $lang['info_invoicepage'] = '<strong>Note:</strong> This page is also used as the success and failure page for payment gateways';
 $lang['inform_no_cc_processing'] = 'Are you aware that you are merely editing existing payment information?\nNo new credit card transaction will be processed.';
 $lang['info_order_notes'] = 'Supply some special notes for this order';
+$lang['info_require_membergroup'] = 'This setting only applies if NOT allowing anonymous users to perform checkout';
 $lang['info_skip_invoice_page'] = 'When allowing users to specify payment information,<br/>should they then procede to the invoice page,<br/>or directly to the transaction completion page?';
 $lang['info_store_creditcard_data'] = '<strong>Note: <span style=&quot;color: red;&quot;>Not Recommended</span></strong> This option stores the user entered credit card information in the database for later use in the admin panel.  Although encryption is used to store private data it cannot be considered to be secure.  It is recommended that this option never be used.  Instead, please use a compatible payment gateway module.';
 $lang['info_useremail_template'] = 'This template controls the layout and content of the email that is sent to the user when a new order is submitted';
@@ -248,9 +252,9 @@ $lang['next'] = 'N&auml;sta';
 $lang['nextpage'] = '>';
 $lang['no'] = 'nej';
 $lang['no_items_in_cart'] = 'Det finns inga varor i din kundvagn. V&auml;nligen l&auml;gg till en vara innan du kan godk&auml;nna din best&auml;llning ';
-$lang['no_report_data'] = 'No matching data found';
+$lang['no_report_data'] = 'Ingen data matchades';
 $lang['none'] = 'Ingen';
-$lang['notcancelledshipped'] = 'Any but Cancelled or Shipped';
+$lang['notcancelledshipped'] = 'Inst&auml;llda eller fraktade';
 $lang['notes'] = 'Noteringar';
 $lang['notshipped'] = 'Ej levererad';
 $lang['num'] = 'Nr.';
@@ -303,6 +307,7 @@ $lang['promotions_settings'] = 'Promotions Settings';
 $lang['prompt_address_property_map'] = 'Address to FEU Property Map';
 $lang['prompt_address_retrieval'] = 'Address Retrieval Method';
 $lang['prompt_admin_invoice_template'] = 'Printable Invoice Template';
+$lang['prompt_allow_anon_checkout'] = 'Allow anonymous users to checkout';
 $lang['prompt_allow_creditcard_entry'] = 'Till&aring;t kunder att l&auml;gga till kreditkorts information';
 $lang['prompt_billingpage'] = 'Page to assume that the billing form will be displayed on.  This is usually the page with your <code>{Orders}</code> tag.';
 $lang['prompt_ccprocessing_module'] = 'Credit Card Processing Gateway';
@@ -340,6 +345,7 @@ $lang['regex'] = 'Regular Expression';
 $lang['remember_last_address_used'] = 'Use the address from the last order';
 $lang['report'] = 'Report';
 $lang['reports'] = 'Reports';
+$lang['report_recent_payments'] = 'Recent Payments';
 $lang['report_shipping_costs'] = 'Shipping Costs';
 $lang['report_subscr_picklist'] = 'Subscription Picklist';
 $lang['report_templates'] = 'Report Templates';
@@ -375,6 +381,7 @@ $lang['subject'] = '&Auml;mne';
 $lang['submit'] = 'Spara';
 $lang['submitted'] = 'Sparad';
 $lang['submit_payment_info'] = 'Spara betalningsinfo';
+$lang['subscribed'] = 'Subscribed';
 $lang['subtotal'] = 'Delsumma';
 $lang['tax'] = 'Skatt';
 $lang['tax_module'] = 'Skattmodul';
@@ -416,9 +423,9 @@ $lang['warning_order_paid_in_full'] = '<strong>Warning!</strong> This order alre
 $lang['weight'] = 'Vikt';
 $lang['within'] = 'Inom';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.510945101.1268575315.1275941581.1275944571.71';
-$lang['utmz'] = '156861353.1275424435.57.14.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
-$lang['qca'] = 'P0-256326421-1268575315457';
+$lang['utma'] = '156861353.1779670065.1310491113.1310491113.1310491113.1';
+$lang['utmz'] = '156861353.1310491113.1.1.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['qca'] = 'P0-1529175659-1310081076901';
+$lang['utmb'] = '156861353.3.10.1310491113';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1275944571';
 ?>
\ No newline at end of file
