@@ -101,6 +101,7 @@ class order_maker
     $new_addr_array = array();
     foreach( $addr_map as $key => $value )
       {
+	if( $key == '' || $key == -1 ) continue;
 	if( $value == -1 )
 	  {
 	    $new_addr_array[$key] = '';
@@ -179,6 +180,7 @@ class order_maker
     $new_line_item->set_unit_price($basket_item->get_unit_price());
     $new_line_item->set_weight($basket_item->get_unit_weight());
     $new_line_item->set_description($basket_item->get_summary());
+    $new_line_item->set_discount($basket_item->get_unit_discount());
     $new_line_item->set_status(ITEMSTATUS_NOTSHIPPED);
     $new_line_item->set_sku($basket_item->get_sku());
     $new_line_item->set_source($basket_item->get_source());
@@ -220,16 +222,30 @@ class order_maker
 
   protected function _adjust_line_items_for_discounts($uid,&$items)
   {
+    if( !is_array($items) || count($items) == 0 )
+      {
+	return FALSE;
+      }
+
+    $new_items = array();
+    $params = array();
+    $params['uid'] = $uid;
+    $params['items'] = $items;
+    $params['new_items'] =& $new_items;
+    Events::SendEvent('Orders','CalculateDiscounts',$params);
+
+    if( isset($params['new_items']) && is_array($params['new_items']) && count($params['new_items']) )
+      {
+	$items = $params['new_items'];
+      }
+
+    // this stuff is deprecated... make promotions listen to the event.
     $promotionsmodule = cg_ecomm::get_promotions_module();
     if( !$promotionsmodule )
       {
 	// no promotions module
 	return FALSE;
       }
-    if( !is_array($items) || count($items) == 0 )
-      {
-	return FALSE;
-      }
 
     // calculate a subtotal, and a weight
     $subtotal = 0;
@@ -251,6 +267,43 @@ class order_maker
   }
 
 
+  private function _calculate_item_taxes(line_item $oneitem,&$cumulative_taxes)
+  {
+    $taxmodule = cg_ecomm::get_tax_module();
+    if( !$taxmodule )
+      {
+	// no tax module
+	return FALSE;
+      }
+
+    $tax_array = '';
+    if( method_exists($taxmodule,'get_taxes_for_item') )
+      {
+	$tax_array = $taxmodule->get_taxes_for_item($oneitem);
+      }
+    else
+      {
+	$tax_array = $taxmodule->GetTaxesForProduct($oneitem->get_net_price(),
+						    $oneitem->get_quantity());
+      }
+    if( $tax_array )
+      {
+	foreach( $tax_array as $key => $value )
+	  {
+	    if( !isset($cumulative_taxes[$key]) )
+	      {
+		$cumulative_taxes[$key] = 0;
+	      }
+	    $cumulative_taxes[$key] += $value;
+	  }
+
+	return TRUE;
+      }
+
+    return FALSE;
+  }
+
+
   protected function _calculate_taxes(cge_address &$billing_address,&$items)
   {
     // Get the tax module
@@ -276,37 +329,28 @@ class order_maker
 	    switch( $oneitem->get_item_type() )
 	      {
 	      case line_item::ITEMTYPE_SERVICE:
+		$this->_calculate_item_taxes($oneitem,$results);
+		break;
+
 	      case line_item::ITEMTYPE_SHIPPING:
+		$this->_calculate_item_taxes($oneitem,$results);
+		break;
+
 	      case line_item::ITEMTYPE_PRODUCT:
 		$source = $oneitem->get_source();
 		$taxable = FALSE;
 		if( $source != '' && cg_ecomm::is_supplier_module($source) )
 		  {
-		    $taxable = cge_utils::get_module($source)->is_taxable($oneitem->get_item_id());
+		    $mod = cge_utils::get_module($source);
+		    if( method_exists($mod,'is_taxable')  )
+		      {
+			$taxable = $mod->is_taxable($oneitem->get_item_id());
+		      }
 		  }
+
 		if( $taxable )
 		  {
-		    $tax_array = '';
-		    if( method_exists($taxmodule,'get_taxes_for_item') )
-		      {
-			$tax_array = $taxmodule->get_taxes_for_item($oneitem);
-		      }
-		    else
-		      {
-			$tax_array = $taxmodule->GetTaxesForProduct($oneitem->get_net_price(),
-								    $oneitem->get_quantity());
-		      }
-		    if( $tax_array )
-		      {
-			foreach( $tax_array as $key => $value )
-			  {
-			    if( !isset($results[$key]) )
-			      {
-				$results[$key] = 0;
-			      }
-			    $results[$key] += $value;
-			  }
-		      }
+		    $this->_calculate_item_taxes($oneitem,$results);
 		  }
 		break;
 
@@ -378,10 +422,18 @@ class order_maker
     if( $shipping_cost !== FALSE )
       {
 	$line_item = new line_item();
-	$line_item->set_description($this->_this_module->Lang('shipping'));
 	$line_item->set_quantity(1);
-	$line_item->set_unit_price($shipping_cost);
 	$line_item->set_item_type(line_item::ITEMTYPE_SHIPPING);
+	if( is_array($shipping_cost) )
+	  {
+	    $line_item->set_decription($shipping_cost[0]);
+	    $line_item->set_unit_price($shipping_cost[1]);
+	  }
+	else
+	  {
+	    $line_item->set_description($this->_this_module->Lang('shipping'));
+	    $line_item->set_unit_price($shipping_cost);
+	  }
       }
     return $line_item;
   }
@@ -433,7 +485,7 @@ class order_maker
 	    if( count($cart_items) )
 	      {
 		$shipping_cost = $shipping_module->CalculateShipping($cart_items);
-		if( $shipping_cost !== FALSE )
+		if( $shipping_cost !== FALSE && $shipping_cost != '0' )
 		  {
 		    $line_item = new line_item();
 		    $line_item->set_description($this->_this_module->Lang('shipping'));
@@ -487,11 +539,20 @@ class order_maker
 	return $order;
       }
 
+    // now get the stuff out of the cart into the order.
+    $basket_names = $this->_cart_module->GetBasketNames($this->_uid);
+    if( !is_array($basket_names) || count($basket_names) <= 0 )
+      {
+	// no baskets, so no order.
+	return $order;
+      }
+
+
     // start building the order
     $order = new orders_order();
     $order->set_feu_user($this->_uid);
-
     $order->set_status(ORDERSTATUS_PROPOSED);
+    $billing_addr = '';
 
     // start with the billing address...
     if( $this->_billing_address_policy == order_maker::ADDR_POLICY_FEU )
@@ -504,20 +565,32 @@ class order_maker
       }
     else if( $this->_billing_address_policy == order_maker::ADDR_POLICY_COOKIE )
       {
-	if( $_COOKIE['my_address'] )
+	if( isset($_COOKIE['my_address']) )
 	  {
-	    $billing_addr = unserialize(base64_decode($_COOKIE['my_address']));
+	    if( startswith('e:',$data) )
+	      {
+		// encrypted
+		$orders = cms_utils::get_module('Orders');
+		$data = substr($_COOKIE['my_address'],2);
+		$data = base64_decode($data);
+		$data = cge_encrypt::decrypt($orders->GetPreference('encryption_key'),$data);
+		$billing_addr = unserialize($data);
+	      }
+	    else
+	      {
+		// old style, not encrypted.
+		$data = unserialize(base64_decode($_COOKIE['my_address']));
+		$billing_addr = unserialize(base64_decode($_COOKIE['my_address']));
+	      }
 	  }
       }
 
-    if( !$billing_addr )
+    if( !is_object($billing_addr) )
       {
 	$billing_addr = new orders_address();
       }
     $order->set_billing($billing_addr);
 
-    // now get the stuff out of the cart into the order.
-    $basket_names = $this->_cart_module->GetBasketNames($this->_uid);
     foreach( $basket_names as $one_basket_name )
       {
 	$basket_details = $this->_cart_module->GetBasketDetails($one_basket_name,$this->_uid);
@@ -581,8 +654,11 @@ class order_maker
   {
     if( $this->_billing_address_policy == order_maker::ADDR_POLICY_COOKIE )
       {
-	$data = base64_encode(serialize($address));
-	@setcookie('my_address',$data,time()+(365*24*60*60));
+	$orders = cms_utils::get_module('Orders');
+	$data = cge_encrypt::encrypt($orders->GetPreference('encryption_key'),serialize($address));
+	if( !$data ) return;
+	$data = base64_encode($data);
+	@setcookie('my_address','e:'.$data,time()+(365*24*60*60));
       }
   }
 } // end of class
